@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.005001'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use Moose;
 with (
@@ -11,8 +11,10 @@ with (
 	'Dist::Zilla::Role::FileFinderUser' => {
 		default_finders => [ ':InstallModules', ':ExecFiles' ],
 	},
+	'Dist::Zilla::Role::PPI',
 );
 
+use Carp qw( confess );
 use PPI;
 use MooseX::Types::Perl qw( LaxVersionStr );
 use namespace::autoclean;
@@ -35,17 +37,9 @@ sub munge_file {
 	my $version = $self->zilla->version;
 
 	confess 'invalid characters in version'
-		unless LaxVersionStr->check( $version );
+		unless LaxVersionStr->check( $version );  ## no critic (Modules::RequireExplicitInclusion)
 
-	my $content = $file->content;
-
-	my $doc = PPI::Document->new(\$content)
-		or $self->log( 'Skipping: "'
-			. $file->name
-			.  '" error with PPI: '
-			. PPI::Document->errstr
-			)
-			;
+	my $doc = $self->ppi_document_for_file($file);
 
 	return unless defined $doc;
 
@@ -54,16 +48,16 @@ sub munge_file {
 	my $version_regex
 		= q{
                   ^
-                  (\s*)           # capture all whitespace before comment
+                  (\s*)              # capture all whitespace before comment
                   (
-                    \#\s*VERSION  # capture # VERSION
-                    \b            # and ensure it ends on a word boundary
-                    [             # conditionally
-                      [:print:]   # all printable characters after VERSION
-                      \s          # any whitespace including newlines see GH #5
-                    ]*            # as many of the above as there are
+                    \#\#?\s*VERSION  # capture # VERSION or ## VERSION
+                    \b               # and ensure it ends on a word boundary
+                    [                # conditionally
+                      [:print:]      # all printable characters after VERSION
+                      \s             # any whitespace including newlines - GH #5
+                    ]*               # as many of the above as there are
                   )
-                  $               # until the EOL}
+                  $                  # until the EOL}
 		;
 
 	my $munged_version = 0;
@@ -79,13 +73,13 @@ sub munge_file {
 						. qq{'; $comment}
 						;
 				$_->set_content("$code");
-				$file->content( $doc->serialize );
 				$munged_version++;
 			}
 		}
 	}
 
 	if ( $munged_version ) {
+		$self->save_ppi_document_to_file( $doc, $file);
 		$self->log_debug([ 'adding $VERSION assignment to %s', $file->name ]);
 	}
 	else {
@@ -98,7 +92,7 @@ sub munge_file {
 }
 __PACKAGE__->meta->make_immutable;
 1;
-# ABSTRACT: no line insertion and does Package version with our
+# ABSTRACT: No line insertion and does Package version with our
 
 __END__
 
@@ -106,11 +100,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::OurPkgVersion - no line insertion and does Package version with our
+Dist::Zilla::Plugin::OurPkgVersion - No line insertion and does Package version with our
 
 =head1 VERSION
 
-version 0.005001
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -195,6 +189,18 @@ becomes
 	our $VERSION = '0.1.0'; # VERSION: generated by DZP::OurPkgVersion
 	...
 
+you can also use perltidy's default static side comments (##)
+
+	...
+	## VERSION
+	...
+
+becomes
+
+	...
+	our $VERSION = '0.1.0'; ## VERSION
+	...
+
 Also note, the package line is not in any way significant, it will insert the
 C<our $VERSION> line anywhere in the file before C<# VERSION> as many times as
 you've written C<# VERSION> regardless of whether or not inserting it there is
@@ -227,7 +233,7 @@ tells which files to munge, see L<Dist::Zilla::Role::FileMunger>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/dist-zilla-plugin-ourpkgversion/issues
+https://github.com/plicease/dist-zilla-plugin-ourpkgversion/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -235,6 +241,8 @@ feature.
 
 =head1 CONTRIBUTORS
 
+=for stopwords Alexandr Ciornii Alexei Znamensky Christian Walde Christopher J. Madsen David Golden Graham Ollis Ian Sealy
+
 =over 4
 
 =item *
@@ -257,15 +265,37 @@ Christopher J. Madsen <perl@cjmweb.net>
 
 David Golden <dagolden@cpan.org>
 
+=item *
+
+Graham Ollis <perl@wdlabs.com>
+
+=item *
+
+Graham Ollis <plicease@cpan.org>
+
+=item *
+
+Ian Sealy <git@iansealy.com>
+
 =back
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Caleb Cushing <xenoterracide@gmail.com>
 
+=item *
+
+Grahan Ollis <plicease@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Caleb Cushing.
+This software is Copyright (c) 2016 by Caleb Cushing.
 
 This is free software, licensed under:
 
